@@ -427,11 +427,13 @@ func (o PruneImagesOptions) Run() error {
 		registryPinger        imageprune.RegistryPinger
 	)
 
-	if o.Confirm {
+	registryPinger = &imageprune.DryRunRegistryPinger{}
+	registryClientFactory = imageprune.FakeRegistryClientFactory
+	if o.Confirm && o.PruneRegistry != nil && *o.PruneRegistry {
 		if len(registryHost) == 0 {
 			registryHost, err = imageprune.DetermineRegistryHost(allImages, allStreams)
 			if err != nil {
-				return fmt.Errorf("unable to determine registry: %v", err)
+				return fmt.Errorf("unable to find the remote registry host: %v", err)
 			}
 		}
 
@@ -453,9 +455,6 @@ func (o PruneImagesOptions) Run() error {
 			Client:   registryClient,
 			Insecure: insecure,
 		}
-	} else {
-		registryPinger = &imageprune.DryRunRegistryPinger{}
-		registryClientFactory = imageprune.FakeRegistryClientFactory
 	}
 
 	// verify the registy connection now to avoid future surprises
